@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a single column in a worksheet.',
                                   class => 'Column',
                                   required => [], # TODO
 }                                 );
@@ -129,35 +129,35 @@ __PACKAGE__->method_documentation({
      'group_level' => {
      	datatype => 'int',
      	base_name => 'GroupLevel',
-     	description => '',
+     	description => 'Gets the group level of the column.',
      	format => '',
      	read_only => '',
      		},
      'index' => {
      	datatype => 'int',
      	base_name => 'Index',
-     	description => '',
+     	description => 'Gets the index of this column.',
      	format => '',
      	read_only => '',
      		},
      'is_hidden' => {
      	datatype => 'boolean',
      	base_name => 'IsHidden',
-     	description => '',
+     	description => 'Indicates whether the column is hidden.',
      	format => '',
      	read_only => '',
      		},
      'width' => {
      	datatype => 'double',
      	base_name => 'Width',
-     	description => '',
+     	description => 'Gets and sets the column width in unit of characters.',
      	format => '',
      	read_only => '',
      		},
      'style' => {
      	datatype => 'LinkElement',
      	base_name => 'Style',
-     	description => '',
+     	description => 'Gets the style of this column.',
      	format => '',
      	read_only => '',
      		},
