@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -121,7 +121,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents error bar of data series.',
                                   class => 'ErrorBar',
                                   required => [], # TODO
 }                                 );
@@ -138,42 +138,42 @@ __PACKAGE__->method_documentation({
      'amount' => {
      	datatype => 'double',
      	base_name => 'Amount',
-     	description => '',
+     	description => 'Represents amount of error bar.                         The amount must be greater than or equal to zero.',
      	format => '',
      	read_only => '',
      		},
      'display_type' => {
      	datatype => 'string',
      	base_name => 'DisplayType',
-     	description => '',
+     	description => 'Represents error bar display type.',
      	format => '',
      	read_only => '',
      		},
      'minus_value' => {
      	datatype => 'string',
      	base_name => 'MinusValue',
-     	description => '',
+     	description => 'Represents negative error amount when error bar type is Custom.',
      	format => '',
      	read_only => '',
      		},
      'plus_value' => {
      	datatype => 'string',
      	base_name => 'PlusValue',
-     	description => '',
+     	description => 'Represents positive error amount when error bar type is Custom.',
      	format => '',
      	read_only => '',
      		},
      'show_marker_t_top' => {
      	datatype => 'boolean',
      	base_name => 'ShowMarkerTTop',
-     	description => '',
+     	description => 'Indicates if formatting error bars with a T-top.',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => '',
+     	description => 'Represents error bar amount type.',
      	format => '',
      	read_only => '',
      		},
