@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Encapsulates the object that represents a horizontal page break.           ',
                                   class => 'HorizontalPageBreak',
                                   required => [], # TODO
 }                                 );
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'row' => {
      	datatype => 'int',
      	base_name => 'Row',
-     	description => '',
+     	description => 'Gets the zero based row index. ',
      	format => '',
      	read_only => '',
      		},
      'end_column' => {
      	datatype => 'int',
      	base_name => 'EndColumn',
-     	description => '',
+     	description => 'Gets the end column index of this horizontal page break. ',
      	format => '',
      	read_only => '',
      		},
      'start_column' => {
      	datatype => 'int',
      	base_name => 'StartColumn',
-     	description => '',
+     	description => 'Gets the start column index of this horizontal page break. ',
      	format => '',
      	read_only => '',
      		},    
