@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Allows to specify options when rendering worksheet to images, printing worksheet or rendering chart to image.',
                                   class => 'ImageOrPrintOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'text_cross_type' => {
      	datatype => 'string',
      	base_name => 'TextCrossType',
-     	description => '',
+     	description => 'TextCrossType',
      	format => '',
      	read_only => '',
      		},
      'gridline_type' => {
      	datatype => 'string',
      	base_name => 'GridlineType',
-     	description => '',
+     	description => 'GridlineType',
      	format => '',
      	read_only => '',
      		},
@@ -247,28 +247,28 @@ __PACKAGE__->method_documentation({
      'default_edit_language' => {
      	datatype => 'string',
      	base_name => 'DefaultEditLanguage',
-     	description => '',
+     	description => 'DefaultEditLanguage',
      	format => '',
      	read_only => '',
      		},
      'tiff_color_depth' => {
      	datatype => 'string',
      	base_name => 'TiffColorDepth',
-     	description => '',
+     	description => 'ColorDepth',
      	format => '',
      	read_only => '',
      		},
      'tiff_compression' => {
      	datatype => 'string',
      	base_name => 'TiffCompression',
-     	description => '',
+     	description => 'TiffCompression',
      	format => '',
      	read_only => '',
      		},
      'printing_page' => {
      	datatype => 'string',
      	base_name => 'PrintingPage',
-     	description => '',
+     	description => 'PrintingPageType',
      	format => '',
      	read_only => '',
      		},
@@ -282,7 +282,7 @@ __PACKAGE__->method_documentation({
      'image_type' => {
      	datatype => 'string',
      	base_name => 'ImageType',
-     	description => '',
+     	description => 'ImageType',
      	format => '',
      	read_only => '',
      		},
@@ -296,7 +296,7 @@ __PACKAGE__->method_documentation({
      'tiff_binarization_method' => {
      	datatype => 'string',
      	base_name => 'TiffBinarizationMethod',
-     	description => '',
+     	description => 'ImageBinarizationMethod',
      	format => '',
      	read_only => '',
      		},    
