@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents an OleObject in a worksheet.',
                                   class => 'OleObject',
                                   required => [], # TODO
 }                                 );
@@ -130,49 +130,49 @@ __PACKAGE__->method_documentation({
      'display_as_icon' => {
      	datatype => 'boolean',
      	base_name => 'DisplayAsIcon',
-     	description => '',
+     	description => 'True if the specified object is displayed as an icon                         and the image will not be auto changed.',
      	format => '',
      	read_only => '',
      		},
      'file_format_type' => {
      	datatype => 'string',
      	base_name => 'FileFormatType',
-     	description => '',
+     	description => 'Gets and sets the file type of the embedded ole object data',
      	format => '',
      	read_only => '',
      		},
      'image_source_full_name' => {
      	datatype => 'string',
      	base_name => 'ImageSourceFullName',
-     	description => '',
+     	description => 'Gets or sets the path and name of the source file for the linked image.',
      	format => '',
      	read_only => '',
      		},
      'is_auto_size' => {
      	datatype => 'boolean',
      	base_name => 'IsAutoSize',
-     	description => '',
+     	description => 'True indicates that the size of the ole object will be auto changed as the size of snapshot of the embedded content                        when the ole object is activated.',
      	format => '',
      	read_only => '',
      		},
      'is_link' => {
      	datatype => 'boolean',
      	base_name => 'IsLink',
-     	description => '',
+     	description => 'Returns true if the OleObject links to the file.',
      	format => '',
      	read_only => '',
      		},
      'prog_id' => {
      	datatype => 'string',
      	base_name => 'ProgID',
-     	description => '',
+     	description => 'Gets or sets the ProgID of the OLE object.',
      	format => '',
      	read_only => '',
      		},
      'source_full_name' => {
      	datatype => 'string',
      	base_name => 'SourceFullName',
-     	description => '',
+     	description => 'Returns the source full name of the source file for the linked OLE object.',
      	format => '',
      	read_only => '',
      		},
