@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Encapsulates the object that represents a range of cells within a spreadsheet.           ',
                                   class => 'Range',
                                   required => [], # TODO
 }                                 );
