@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents a scroll bar object.',
                                   class => 'ScrollBar',
                                   required => [], # TODO
 }                                 );
@@ -130,49 +130,49 @@ __PACKAGE__->method_documentation({
      'current_value' => {
      	datatype => 'int',
      	base_name => 'CurrentValue',
-     	description => '',
+     	description => 'Gets or sets the current value.',
      	format => '',
      	read_only => '',
      		},
      'incremental_change' => {
      	datatype => 'int',
      	base_name => 'IncrementalChange',
-     	description => '',
+     	description => 'Gets or sets the amount that the scroll bar or spinner is incremented a line scroll.',
      	format => '',
      	read_only => '',
      		},
      'is_horizontal' => {
      	datatype => 'boolean',
      	base_name => 'IsHorizontal',
-     	description => '',
+     	description => 'Indicates whether this is a horizontal scroll bar.',
      	format => '',
      	read_only => '',
      		},
      'max' => {
      	datatype => 'int',
      	base_name => 'Max',
-     	description => '',
+     	description => 'Gets or sets the maximum value of a scroll bar or spinner range.',
      	format => '',
      	read_only => '',
      		},
      'min' => {
      	datatype => 'int',
      	base_name => 'Min',
-     	description => '',
+     	description => 'Gets or sets the minimum value of a scroll bar or spinner range.',
      	format => '',
      	read_only => '',
      		},
      'page_change' => {
      	datatype => 'int',
      	base_name => 'PageChange',
-     	description => '',
+     	description => 'Gets or sets page change',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => '',
+     	description => 'Indicates whether the shape has 3-D shading.',
      	format => '',
      	read_only => '',
      		},
