@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -35,6 +35,7 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
+use AsposeCellsCloud::Object::DataSource;
 use AsposeCellsCloud::Object::FileSource;
 use AsposeCellsCloud::Object::TaskParameter; 
 
@@ -119,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents split workbook task parameter.',
                                   class => 'SplitWorkbookTaskParameter',
                                   required => [], # TODO
 }                                 );
@@ -129,42 +130,56 @@ __PACKAGE__->method_documentation({
      'workbook' => {
      	datatype => 'FileSource',
      	base_name => 'Workbook',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'destination_file_position' => {
      	datatype => 'FileSource',
      	base_name => 'DestinationFilePosition',
-     	description => '',
+     	description => 'Represents data source of task object.',
+     	format => '',
+     	read_only => '',
+     		},
+     'data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'DataSource',
+     	description => 'Represents destination data source.',
+     	format => '',
+     	read_only => '',
+     		},
+     'target_data_source' => {
+     	datatype => 'DataSource',
+     	base_name => 'TargetDataSource',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},
      'destination_file_format' => {
      	datatype => 'string',
      	base_name => 'DestinationFileFormat',
-     	description => '',
+     	description => 'Represents destination data file format.',
      	format => '',
      	read_only => '',
      		},
      'split_name_rule' => {
      	datatype => 'string',
      	base_name => 'SplitNameRule',
-     	description => '',
+     	description => 'SheetName /NewGuid',
      	format => '',
      	read_only => '',
      		},
      'vertical_resolution' => {
      	datatype => 'int',
      	base_name => 'VerticalResolution',
-     	description => '',
+     	description => 'When destination file format is image , vertical resolution can not be null.',
      	format => '',
      	read_only => '',
      		},
      'horizontal_resolution' => {
      	datatype => 'int',
      	base_name => 'HorizontalResolution',
-     	description => '',
+     	description => 'When destination file format is image , horizontal resolution can not be null.',
      	format => '',
      	read_only => '',
      		},    
@@ -173,6 +188,8 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->swagger_types( {
     'workbook' => 'FileSource',
     'destination_file_position' => 'FileSource',
+    'data_source' => 'DataSource',
+    'target_data_source' => 'DataSource',
     'destination_file_format' => 'string',
     'split_name_rule' => 'string',
     'vertical_resolution' => 'int',
@@ -182,6 +199,8 @@ __PACKAGE__->swagger_types( {
 __PACKAGE__->attribute_map( {
     'workbook' => 'Workbook',
     'destination_file_position' => 'DestinationFilePosition',
+    'data_source' => 'DataSource',
+    'target_data_source' => 'TargetDataSource',
     'destination_file_format' => 'DestinationFileFormat',
     'split_name_rule' => 'SplitNameRule',
     'vertical_resolution' => 'VerticalResolution',
