@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Represents the top 10 filter.           ',
                                   class => 'Top10Filter',
                                   required => [], # TODO
 }                                 );
@@ -128,28 +128,28 @@ __PACKAGE__->method_documentation({
      'criteria' => {
      	datatype => 'string',
      	base_name => 'Criteria',
-     	description => '',
+     	description => ' ',
      	format => '',
      	read_only => '',
      		},
      'is_percent' => {
      	datatype => 'boolean',
      	base_name => 'IsPercent',
-     	description => '',
+     	description => 'Indicates whether the items is percent. ',
      	format => '',
      	read_only => '',
      		},
      'is_top' => {
      	datatype => 'boolean',
      	base_name => 'IsTop',
-     	description => '',
+     	description => 'Indicates whether it`s top filter. ',
      	format => '',
      	read_only => '',
      		},
      'items' => {
      	datatype => 'int',
      	base_name => 'Items',
-     	description => '',
+     	description => 'Gets and sets the items of the filter. ',
      	format => '',
      	read_only => '',
      		},    
