@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => '           Encapsulates the object that represents a vertical page break.           ',
                                   class => 'VerticalPageBreak',
                                   required => [], # TODO
 }                                 );
@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'column' => {
      	datatype => 'int',
      	base_name => 'Column',
-     	description => '',
+     	description => 'Gets the column index of the vertical page break. ',
      	format => '',
      	read_only => '',
      		},
      'end_row' => {
      	datatype => 'int',
      	base_name => 'EndRow',
-     	description => '',
+     	description => 'Gets the end row index of the vertical page break. ',
      	format => '',
      	read_only => '',
      		},
      'start_row' => {
      	datatype => 'int',
      	base_name => 'StartRow',
-     	description => '',
+     	description => 'Gets the start row index of the vertical page break. ',
      	format => '',
      	read_only => '',
      		},    
