@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,13 +59,13 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorksheetPivotTableFilterRequest.name :   ,
-# DeleteWorksheetPivotTableFilterRequest.sheetName :   ,
-# DeleteWorksheetPivotTableFilterRequest.pivotTableIndex :   ,
-# DeleteWorksheetPivotTableFilterRequest.fieldIndex :   ,
-# DeleteWorksheetPivotTableFilterRequest.needReCalculate :   ,
-# DeleteWorksheetPivotTableFilterRequest.folder :   ,
-# DeleteWorksheetPivotTableFilterRequest.storageName :    
+# DeleteWorksheetPivotTableFilterRequest.name : The file name.  ,
+# DeleteWorksheetPivotTableFilterRequest.sheetName : The worksheet name.  ,
+# DeleteWorksheetPivotTableFilterRequest.pivotTableIndex : Gets the PivotTable report by index.  ,
+# DeleteWorksheetPivotTableFilterRequest.fieldIndex : Gets the PivotField Object at the specific index.  ,
+# DeleteWorksheetPivotTableFilterRequest.needReCalculate : Whether the specific PivotTable calculate(true/false).  ,
+# DeleteWorksheetPivotTableFilterRequest.folder : The folder where the file is situated.  ,
+# DeleteWorksheetPivotTableFilterRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -76,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_pivot_table_filter' } = { 
-    	summary => '',
+    	summary => 'Delete a pivot filter in the PivotTable.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -149,49 +149,49 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'pivot_table_index' => {
      	datatype => 'int',
      	base_name => 'pivotTableIndex',
-     	description => '',
+     	description => 'Gets the PivotTable report by index.',
      	format => '',
      	read_only => '',
      		},
      'field_index' => {
      	datatype => 'int',
      	base_name => 'fieldIndex',
-     	description => '',
+     	description => 'Gets the PivotField Object at the specific index.',
      	format => '',
      	read_only => '',
      		},
      'need_re_calculate' => {
      	datatype => 'string',
      	base_name => 'needReCalculate',
-     	description => '',
+     	description => 'Whether the specific PivotTable calculate(true/false).',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
