@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetPivotTableFiltersRequest.name :   ,
-# GetWorksheetPivotTableFiltersRequest.sheetName :   ,
-# GetWorksheetPivotTableFiltersRequest.pivotTableIndex :   ,
-# GetWorksheetPivotTableFiltersRequest.folder :   ,
-# GetWorksheetPivotTableFiltersRequest.storageName :    
+# GetWorksheetPivotTableFiltersRequest.name : The file name.  ,
+# GetWorksheetPivotTableFiltersRequest.sheetName : The worksheet name.  ,
+# GetWorksheetPivotTableFiltersRequest.pivotTableIndex : The PivotTable index.  ,
+# GetWorksheetPivotTableFiltersRequest.folder : The folder where the file is situated.  ,
+# GetWorksheetPivotTableFiltersRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_pivot_table_filters' } = { 
-    	summary => '',
+    	summary => 'Gets PivotTable filters in worksheet.',
         params => $params,
         returns => 'PivotFiltersResponse',
     };
@@ -137,35 +137,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'pivot_table_index' => {
      	datatype => 'int',
      	base_name => 'pivotTableIndex',
-     	description => '',
+     	description => 'The PivotTable index.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
