@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,12 +59,12 @@ sub new {
 
 
 # Run Operation Request
-# PostHideWorksheetRowsRequest.name : The workbook name.  ,
+# PostHideWorksheetRowsRequest.name : The file name.  ,
 # PostHideWorksheetRowsRequest.sheetName : The worksheet name.  ,
 # PostHideWorksheetRowsRequest.startrow : The begin row index to be operated.  ,
 # PostHideWorksheetRowsRequest.totalRows : Number of rows to be operated.  ,
-# PostHideWorksheetRowsRequest.folder : Original workbook folder.  ,
-# PostHideWorksheetRowsRequest.storageName : Storage name.   
+# PostHideWorksheetRowsRequest.folder : The folder where the file is situated.  ,
+# PostHideWorksheetRowsRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -140,7 +140,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -168,14 +168,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
