@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PostUpdateWorksheetZoomRequest.name : The workbook name.  ,
+# PostUpdateWorksheetZoomRequest.name : The file name.  ,
 # PostUpdateWorksheetZoomRequest.sheetName : The worksheet name.  ,
 # PostUpdateWorksheetZoomRequest.value : Represents the scaling factor in percentage. It should be between 10 and 400.  ,
-# PostUpdateWorksheetZoomRequest.folder : Original workbook folder.  ,
-# PostUpdateWorksheetZoomRequest.storageName : Storage name.   
+# PostUpdateWorksheetZoomRequest.folder : The folder where the file is situated.  ,
+# PostUpdateWorksheetZoomRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_update_worksheet_zoom' } = { 
-    	summary => 'Updates worksheet zoom.',
+    	summary => 'Update the scaling percentage in the worksheet. It should be between 10 and 400.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -135,7 +135,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -156,14 +156,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
