@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,16 +59,16 @@ sub new {
 
 
 # Run Operation Request
-# PutWorksheetOleObjectRequest.name : The workbook name.  ,
+# PutWorksheetOleObjectRequest.name : The file name.  ,
 # PutWorksheetOleObjectRequest.sheetName : The worsheet name.  ,
 # PutWorksheetOleObjectRequest.upperLeftRow : Upper left row index  ,
 # PutWorksheetOleObjectRequest.upperLeftColumn : Upper left column index  ,
 # PutWorksheetOleObjectRequest.height : Height of oleObject, in unit of pixel  ,
 # PutWorksheetOleObjectRequest.width : Width of oleObject, in unit of pixel  ,
-# PutWorksheetOleObjectRequest.oleFile : OLE filename(full file name).  ,
-# PutWorksheetOleObjectRequest.imageFile : Image filename(full file name).  ,
-# PutWorksheetOleObjectRequest.folder : Original workbook folder.  ,
-# PutWorksheetOleObjectRequest.storageName : Storage name.   
+# PutWorksheetOleObjectRequest.oleFile : OLE filename path(full file name).  ,
+# PutWorksheetOleObjectRequest.imageFile : Image filename path(full file name).  ,
+# PutWorksheetOleObjectRequest.folder : The folder where the file is situated.  ,
+# PutWorksheetOleObjectRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -79,7 +79,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_worksheet_ole_object' } = { 
-    	summary => 'Add an OLE object in worksheet.',
+    	summary => 'Add an OLE object in the worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -160,7 +160,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -202,28 +202,28 @@ __PACKAGE__->method_documentation({
      'ole_file' => {
      	datatype => 'string',
      	base_name => 'oleFile',
-     	description => 'OLE filename(full file name).',
+     	description => 'OLE filename path(full file name).',
      	format => '',
      	read_only => '',
      		},
      'image_file' => {
      	datatype => 'string',
      	base_name => 'imageFile',
-     	description => 'Image filename(full file name).',
+     	description => 'Image filename path(full file name).',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
